For typical usage, a simple pip install will do the trick.

```bash
pip install planck
```

If you've got Python 3.8+ and `pip` installed, you're good to go. 
It is generally recommended to use a virtual environment for the installation. 

  
## Git-based installation
If you need or prefer installing planck from git, you can use:
```bash
pip install git+https://github.com/okube-ai/planck.git@main
```
